==> kdeutils-4.3.5.tar.bz2: kdeutils-4.3.5/okteta/core/piecetable/tests/insertpiecetablechangeabstractpiecetablechangeiftest.cpp <==
/*
    This file is part of the Okteta Core library, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "insertpiecetablechangeabstractpiecetablechangeiftest.h"

// test object
#include <piecetable/insertpiecetablechange.h>
// lib
#include <piecetable/piecetable.h>
// Qt
#include <QtTest/QtTest>


static const int InsertOffset = 30;
static const int InsertLength = 80;
static const int StorageOffset = 67;

namespace KPieceTable
{

AbstractPieceTableChange *InsertPieceTableChangeAbstractPieceTableChangeIfTest::createPieceTableChange()
{
    InsertPieceTableChange *pieceTableChange =
        new InsertPieceTableChange( InsertOffset, InsertLength, StorageOffset );

    return pieceTableChange;
}
void InsertPieceTableChangeAbstractPieceTableChangeIfTest::changePieceTable( PieceTable *pieceTable )
{
    pieceTable->insert( InsertOffset, InsertLength, StorageOffset );
}

void InsertPieceTableChangeAbstractPieceTableChangeIfTest::deletePieceTableChange( AbstractPieceTableChange *pieceTableChange )
{
    delete pieceTableChange;
}

}

QTEST_MAIN( KPieceTable::InsertPieceTableChangeAbstractPieceTableChangeIfTest )

==> kdeutils_4.4.85.orig.tar.bz2: kdeutils-4.4.85/okteta/core/piecetable/tests/insertpiecetablechangeabstractpiecetablechangeiftest.cpp <==
/*
    This file is part of the Okteta Core library, part of the KDE project.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "insertpiecetablechangeabstractpiecetablechangeiftest.h"

// test object
#include <piecetable/insertpiecetablechange.h>
// lib
#include <piecetable/piecetable.h>
// Qt
#include <QtTest/QtTest>


namespace KPieceTable
{

static const Address InsertOffset = 30;
static const Size InsertLength = 80;
static const Address StorageOffset = 67;


AbstractPieceTableChange* InsertPieceTableChangeAbstractPieceTableChangeIfTest::createPieceTableChange()
{
    InsertPieceTableChange* pieceTableChange =
        new InsertPieceTableChange( InsertOffset, InsertLength, StorageOffset );

    return pieceTableChange;
}

void InsertPieceTableChangeAbstractPieceTableChangeIfTest::changePieceTable( PieceTable* pieceTable )
{
    pieceTable->insert( InsertOffset, InsertLength, StorageOffset );
}

void InsertPieceTableChangeAbstractPieceTableChangeIfTest::deletePieceTableChange( AbstractPieceTableChange* pieceTableChange )
{
    delete pieceTableChange;
}

}

QTEST_MAIN( KPieceTable::InsertPieceTableChangeAbstractPieceTableChangeIfTest )
